"""Module containing enums used in the construction of plotly figures.

Contains:
- DashPatterns: Sets out valid dash patterns used by plotly/plotly express.
"""

from .dash_patterns import DashPatterns
